@@ -227,27 +227,27 @@ Moe, moe, kyun!")
    `(undo-tree-visualizer-register-face ((,class (:foreground ,yellow-2))))
 
    ;; Markdown-mode
-   `(markdown-blockquote-face ((,class (:foreground ,green-3 :background ,green-00 :italic t))))
+   `(markdown-blockquote-face ((,class (:foreground ,green-3 :background ,green-00 :italic t :extend t))))
    `(markdown-bold-face ((,class (:foreground ,black-5 :bold t))))
    `(markdown-comment-face ((,class (:foreground ,white-4 :italic t))))
+   `(markdown-header-rule-face ((,class (:foreground ,orange-2 :bold t))))
    `(markdown-header-delimiter-face ((,class (:foreground ,orange-3 :bold t))))
    `(markdown-header-face ((,class (:foreground ,orange-2 :bold t))))
-   `(markdown-header-rule-face ((,class (:foreground ,orange-2 :bold t))))
-   `(markdown-header-face-1 ((,class (:foreground ,orange-2 :bold t))))
-   `(markdown-header-face-2 ((,class (:foreground ,orange-2 :bold t))))
+   `(markdown-header-face-1 ((,class (:foreground ,blue-1 :bold t))))
+   `(markdown-header-face-2 ((,class (:foreground ,green-02 :bold t))))
    `(markdown-header-face-3 ((,class (:foreground ,orange-2 :bold t))))
-   `(markdown-header-face-4 ((,class (:foreground ,orange-2 :bold t))))
-   `(markdown-header-face-5 ((,class (:foreground ,orange-2 :bold t))))
-   `(markdown-header-face-6 ((,class (:foreground ,orange-2 :bold t))))
+   `(markdown-header-face-4 ((,class (:foreground ,cyan-3 :bold t))))
+   `(markdown-header-face-5 ((,class (:foreground ,red-2 :bold t))))
+   `(markdown-header-face-6 ((,class (:foreground ,purple-2 :bold t))))
    `(markdown-link-face ((,class (:foreground ,magenta-1 :bold t :underline ,magenta-1))))
    `(markdown-inline-code-face ((,class (:foreground ,black-4 :background ,white-1))))
-   `(markdown-code-face ((,class (:foreground unspecified :background unspecified))))
+   `(markdown-code-face ((,class (:foreground unspecified :background ,white-1 :extend t))))
+   `(markdown-pre-face ((,class (:foreground ,black-4 :background ,white-1))))
    `(markdown-markup-face  ((,class (:foreground ,black-1 :background unspecified))))
    `(markdown-italic-face ((,class (:foreground ,black-5 :italic t :underline ,black-5))))
    `(markdown-list-face ((,class (:foreground ,orange-2 :background ,LIGHT_BG :bold t))))
    `(markdown-math-face ((,class (:foreground ,purple-2))))
    `(markdown-missing-link-face ((,class (:foreground ,red-1 :bold t))))
-   `(markdown-pre-face ((,class (:foreground ,black-4 :background ,white-1))))
    `(markdown-reference-face ((,class (:foreground ,orange-2 :italic t))))
    `(markdown-url-face ((,class (:foreground ,magenta-3 :underline ,magenta-3))))
 
