@@ -9,8 +9,8 @@
 ;; Keywords: themes
 ;; X-URL: https://github.com/kuanyui/moe-theme.el
 ;; URL: https://github.com/kuanyui/moe-theme.el
-;; Package-Version: 20260206.314
-;; Package-Revision: 536f86bf526f
+;; Package-Version: 20260211.617
+;; Package-Revision: 4d779e8af108
 
 ;; This file is not part of GNU Emacs.
 ;;
@@ -144,7 +144,7 @@ Avoid unnecessary load-theme")
     (setq list (append list '(1.0))))
   list)
 
-(with-eval-after-load "markdown"
+(with-eval-after-load 'markdown-mode
   (defun moe-theme-resize-title-apply-markdown ()
     (setq moe-theme-resize-title-markdown (moe-theme-resize-title--repaire-list moe-theme-resize-title-markdown 6))
     (set-face-attribute 'markdown-header-face-1 nil :height (nth 0 moe-theme-resize-title-markdown))
@@ -155,7 +155,7 @@ Avoid unnecessary load-theme")
     (set-face-attribute 'markdown-header-face-6 nil :height (nth 5 moe-theme-resize-title-markdown)))
   (moe-theme-resize-title-apply-markdown))
 
-(with-eval-after-load "org"
+(with-eval-after-load 'org-mode
   (defun moe-theme-resize-title-apply-org ()
     (setq moe-theme-resize-title-org (moe-theme-resize-title--repaire-list moe-theme-resize-title-org 9))
     (set-face-attribute 'org-document-title nil :height (nth 0 moe-theme-resize-title-org))
@@ -169,7 +169,7 @@ Avoid unnecessary load-theme")
     (set-face-attribute 'org-level-8        nil :height (nth 8 moe-theme-resize-title-org)))
   (moe-theme-resize-title-apply-org))
 
-(with-eval-after-load "rst"
+(with-eval-after-load 'rst-mode
   (defun moe-theme-resize-title-apply-rst ()
     (setq moe-theme-resize-title-rst (moe-theme-resize-title--repaire-list moe-theme-resize-title-rst 6))
     (if (facep 'rst-level-1-face)
